@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Time-stamp: <2013-05-14 16:20:34 vk>
+# Time-stamp: <2014-01-28 16:17:20 vk>
 
 from argparse import ArgumentParser
 from argparse import RawDescriptionHelpFormatter
@@ -103,13 +103,24 @@ class MemacsArgumentParser(ArgumentParser):
                           "its content as STRING",
                           metavar="STRING")
 
+        self.add_argument("--custom-header",
+                          dest="custom_header",
+                          help="if you want to add an arbitrary header line, please specify " + \
+                          "its content as STRING",
+                          metavar="STRING")
+
         self.add_argument("--add-to-time-stamps",
                           dest="timestamp_delta",
                           help="if data is off by, e.g., two hours, you can specify \"+2\" " + \
                               "or \"-2\" here to correct it with plus/minus two hours",
                           metavar="STRING")
 
-
+        self.add_argument("--inactive-time-stamps",
+                          dest="inactive_timestamps",
+                          help="""inactive time-stamps are written to the output file 
+                          instead of active time-stamps. Helps to move modules with many entries
+                          to the inactive layer of the agenda.""",
+                          action="store_true")
 
         # ---------------------
         # Config parser
